@@ -15,16 +15,16 @@ from functools import partial
 from itertools import chain
 from multiprocessing import cpu_count
 from operator import itemgetter
+from os.path import join as pjoin
 
 from snakeoil import klass
-from snakeoil.bash import iter_read_bash, read_bash_dict
+from snakeoil.bash import read_bash, read_bash_dict
 from snakeoil.cli.exceptions import find_user_exception
 from snakeoil.data_source import local_source
 from snakeoil.log import suppress_logging
 from snakeoil.mappings import ImmutableDict, ProtectedDict
-from snakeoil.osutils import pjoin
 from snakeoil.process.spawn import spawn_get_output
-from snakeoil.sequences import predicate_split, split_negations, stable_unique
+from snakeoil.sequences import predicate_split, split_negations, unique_stable
 
 from ..binpkg import repository as binary_repo
 from ..cache.flat_hash import md5_cache
@@ -41,7 +41,6 @@ from ..repository.util import RepositoryGroup
 from ..restrictions import packages, values
 from ..restrictions.delegated import delegate
 from ..util.parserestrict import ParseError, parse_match
-from . import const
 from . import repository as ebuild_repo
 from .atom import atom as _atom
 from .eapi import get_latest_PMS_eapi
@@ -55,6 +54,7 @@ from .misc import (
     optimize_incrementals,
 )
 from .portage_conf import PortageConfig
+from .profiles import INCREMENTALS
 from .repo_objs import Licenses, RepoConfig
 from .triggers import GenerateTriggers
 
@@ -189,7 +189,7 @@ def _read_config_file(path):
         for fs_obj in sorted(iter_scan(path, follow_symlinks=True)):
             if not fs_obj.is_reg or "/." in fs_obj.location:
                 continue
-            for lineno, line in iter_read_bash(
+            for lineno, line in read_bash(
                 fs_obj.location, allow_line_cont=True, enum_line=True
             ):
                 yield line, lineno, fs_obj.location
@@ -298,10 +298,10 @@ class domain(config_domain):
         self._settings = ProtectedDict(settings)
 
     @load_property("/etc/profile.env", read_func=read_bash_dict)
-    def system_profile(self, data):
+    def system_shell_profile(self, data):
         # prepend system profile $PATH if it exists
         if "PATH" in data:
-            path = stable_unique(
+            path = unique_stable(
                 data["PATH"].split(os.pathsep) + os.environ["PATH"].split(os.pathsep)
             )
             os.environ["PATH"] = os.pathsep.join(path)
@@ -319,8 +319,8 @@ class domain(config_domain):
 
         # reformat env.d and make.conf incrementals
         system_profile_settings = {}
-        for x in const.incrementals:
-            system_profile_val = self.system_profile.get(x, ())
+        for x in INCREMENTALS:
+            system_profile_val = self.system_shell_profile.get(x, ())
             make_conf_val = settings.get(x, ())
             if isinstance(system_profile_val, str):
                 system_profile_val = tuple(system_profile_val.split())
@@ -336,11 +336,11 @@ class domain(config_domain):
             if k not in settings:
                 settings[k] = v
                 continue
-            if k in const.incrementals:
+            if k in INCREMENTALS:
                 settings[k] = system_profile_settings[k] + v + settings[k]
 
         # next we finalize incrementals.
-        for incremental in const.incrementals:
+        for incremental in INCREMENTALS:
             # Skip USE/ACCEPT_LICENSE for the time being; hack; we need the
             # negations currently so that pkg iuse induced enablings can be
             # disabled by negations. For example, think of the profile doing
@@ -457,25 +457,25 @@ class domain(config_domain):
     def pkg_keywords(self, data, debug=False):
         if debug:
             return tuple(data)
-        return tuple((x[0], stable_unique(x[1])) for x in data)
+        return tuple((x[0], unique_stable(x[1])) for x in data)
 
     @load_property("package.accept_keywords", parse_func=restriction_payload_splitter)
     def pkg_accept_keywords(self, data, debug=False):
         if debug:
             return tuple(data)
-        return tuple((x[0], stable_unique(x[1])) for x in data)
+        return tuple((x[0], unique_stable(x[1])) for x in data)
 
     @load_property("package.license", parse_func=restriction_payload_splitter)
     def pkg_licenses(self, data, debug=False):
         if debug:
             return tuple(data)
-        return tuple((x[0], stable_unique(x[1])) for x in data)
+        return tuple((x[0], unique_stable(x[1])) for x in data)
 
     @load_property("package.use", parse_func=package_use_splitter)
     def pkg_use(self, data, debug=False):
         if debug:
             return tuple(data)
-        return tuple((x[0], split_negations(stable_unique(x[1]))) for x in data)
+        return tuple((x[0], split_negations(unique_stable(x[1]))) for x in data)
 
     @load_property("package.env")
     def pkg_env(self, data, debug=False):
@@ -511,7 +511,6 @@ class domain(config_domain):
             self._make_keywords_filter(
                 default_keywords,
                 accept_keywords,
-                incremental="package.keywords" in const.incrementals,
             )
         ]
 
@@ -555,7 +554,7 @@ class domain(config_domain):
                 return True
         return False
 
-    def _make_keywords_filter(self, default_keys, accept_keywords, incremental=False):
+    def _make_keywords_filter(self, default_keys, accept_keywords):
         """Generates a restrict that matches iff the keywords are allowed."""
         if not accept_keywords and not self.profile.keywords:
             return packages.PackageRestriction(
@@ -573,24 +572,11 @@ class domain(config_domain):
                 ((packages.AlwaysTrue, default_keys),), (f(*i) for i in accept_keywords)
             )
         else:
-            if incremental:
-                f = collapsed_restrict_to_data
-            else:
-                f = non_incremental_collapsed_restrict_to_data
-            data = f(((packages.AlwaysTrue, default_keys),), accept_keywords)
+            data = non_incremental_collapsed_restrict_to_data(
+                ((packages.AlwaysTrue, default_keys),), accept_keywords
+            )
 
-        if incremental:
-            raise NotImplementedError(self._incremental_apply_keywords_filter)
-        else:
-            f = self._apply_keywords_filter
-        return delegate(partial(f, data))
-
-    @staticmethod
-    def _incremental_apply_keywords_filter(data, pkg, mode):
-        # note we ignore mode; keywords aren't influenced by conditionals.
-        # note also, we're not using a restriction here.  this is faster.
-        allowed = data.pull_data(pkg)
-        return any(True for x in pkg.keywords if x in allowed)
+        return delegate(partial(self._apply_keywords_filter, data))
 
     def _apply_keywords_filter(self, data, pkg, mode):
         # note we ignore mode; keywords aren't influenced by conditionals.
@@ -898,7 +884,7 @@ class domain(config_domain):
         for r in self.__repos:
             try:
                 repo = r.instantiate()
-                if not repo.is_supported:
+                if not repo.supported:
                     logger.warning(
                         f"skipping {r.name!r} repo: unsupported EAPI {str(repo.eapi)!r}"
                     )
